@@ -1,4 +1,5 @@
 import random
+from typing import Any, Union
 
 
 class CartographySelector():
@@ -7,15 +8,14 @@ class CartographySelector():
     represents the ratio of probabilities of any index given the probability of
     the preceeding one. For instance, if the decay rate is set to ``0.75``
     (which is its default value), the probability of the element in index 1 of
-    the input list being selected is 0.75 the probability of the element in
-    index 0, and the probability of the element in index 2 is 0.5625 (0.75^2)
+    the input list being selected is 75% the probability of the element in
+    index 0, and the probability of the element in index 2 is 56.25% (0.75^2)
     the probability of the element in index 0. This is the selector used in my
     *Cartography* series of compositions.
 
-    ..  container:: example
-
-        The selector should be initialised with a list of objects. The contents
-        of the list can be absolutely anything.
+    Example:
+        The selector should be initialised with a list of objects. The elements
+        of this list can be of any type.
 
         >>> selector = auxjad.CartographySelector([0, 1, 2, 3, 4])
         >>> selector.contents
@@ -29,7 +29,7 @@ class CartographySelector():
         >>> selector.weights
         [1.0, 0.75, 0.5625, 0.421875, 0.31640625]
 
-        Applying the ``len()`` function to the selector will give the length
+        Applying the ``len()`` function to the selector will return the length
         of the input list.
 
         >>> len(selector)
@@ -49,8 +49,7 @@ class CartographySelector():
         >>> next(selector)
         0
 
-    ..  container:: example
-
+    Example:
         By default, only the weight function (defined by the decay rate) is
         taken into consideration when selecting an element. This means that
         repeated elements can appear, as shown below.
@@ -72,8 +71,7 @@ class CartographySelector():
         >>> result
         210421021020304024230120241202
 
-    ..  container:: example
-
+    Example:
         The keyword argument ``decay_rate`` can be used to set a different
         decay rate when creating a selector.
 
@@ -97,8 +95,7 @@ class CartographySelector():
         >>> result
         '000001002100000201001030000100'
 
-    ..  container:: example
-
+    Example:
         Appending is a type of content transformation. It discards the first
         element of the selector's ``contents``, shifts all others leftwards,
         and then appends the new element to the last index.
@@ -113,8 +110,7 @@ class CartographySelector():
         >>> selector.contents
         [2, 3, 4, 5, 42]
 
-    ..  container:: example
-
+    Example:
         The method ``append_keeping_n()`` is similar to ``append()``, but it
         keeps the first ``n`` elements of ``contents`` untouched. It thus
         discards the n+1-th element, shifts all the next elements one position
@@ -127,8 +123,7 @@ class CartographySelector():
         >>> selector.contents
         [10, 7, 31, 98, 100]
 
-    ..  container:: example
-
+    Example:
         Prepending is another type of content transformation. It discards the
         last element of the ``contents``, shifts all others rightwards, and
         then prepends the new element to the first index.
@@ -143,8 +138,7 @@ class CartographySelector():
         >>> selector.contents
         [71, -1, 0, 1, 2]
 
-    ..  container:: example
-
+    Example:
         Rotation is another type of content transformation. It rotates all
         elements rightwards, moving the last element to the first index. If the
         optional keyword argument ``anticlockwise`` is set to ``True``, the
@@ -163,8 +157,7 @@ class CartographySelector():
         >>> selector.contents
         [1, 2, 3, 4, 0]
 
-    ..  container:: example
-
+    Example:
         The mirror transformation swaps the element of the input index with its
         complementary element. Complementary elements are defined as the pair
         of elements which share the same distance from the centre of the
@@ -187,8 +180,7 @@ class CartographySelector():
         >>> selector.contents
         [0, 3, 2, 1, 4]
 
-    ..  container:: example
-
+    Example:
         To mirror a random pair of complementary elements, use the
         ``mirror_random()`` method. In case of a selector with an odd number
         of elements, this method will never pick an element at the pivot point
@@ -207,20 +199,18 @@ class CartographySelector():
         >>> selector.contents
         [4, 1, 2, 3, 0]
 
-    ..  container:: example
-
-        The method ``randomise()`` will randomise the position of the elements
-        of a selector's ``contents``.
+    Example:
+        The method ``shuffle()`` will shuffle the position of the elements of
+        the selector's ``contents``.
 
         >>> selector = auxjad.CartographySelector([0, 1, 2, 3, 4])
         >>> selector.contents
         [0, 1, 2, 3, 4]
-        >>> selector.randomise()
+        >>> selector.shuffle()
         >>> selector.contents
         [1, 4, 3, 0, 2]
 
-    ..  container:: example
-
+    Example:
         The contents of a selector can also be altered after it has been
         initialised using the ``contents`` property. The length of the
         contents can change as well.
@@ -240,8 +230,7 @@ class CartographySelector():
         >>> selector.weights
         [1.0, 0.5, 0.25, 0.125, 0.0625, 0.03125, 0.015625]
 
-    ..  container:: example
-
+    Example:
         Use the read-only properties ``previous_result`` and ``previous_index``
         to output the previous result and its index.
 
@@ -254,8 +243,7 @@ class CartographySelector():
         >>> selector.previous_result
         14
 
-    ..  container:: example
-
+    Example:
         The ``contents`` of instances of this class can be indexed and sliced.
         This allows reading, assigning, or deleting values from ``contents``.
 
@@ -283,6 +271,14 @@ class CartographySelector():
         [10, 7, 98]
     """
 
+    ### CLASS VARIABLES ###
+
+    __slots__ = ('_contents',
+                 '_decay_rate',
+                 '_previous_index',
+                 '_weights',
+                 )
+
     ### INITIALISER ###
 
     def __init__(self,
@@ -323,14 +319,14 @@ class CartographySelector():
         if not no_repeat:
             new_index = random.choices(
                 [n for n in range(self.__len__())],
-                weights=self.weights,
+                weights=self._weights,
             )[0]
         else:
             new_index = self._previous_index
-            while (new_index == self._previous_index):
+            while new_index == self._previous_index:
                 new_index = random.choices(
                     [n for n in range(self.__len__())],
-                    weights=self.weights,
+                    weights=self._weights,
                 )[0]
         self._previous_index = new_index
         return self._contents[self._previous_index]
@@ -377,7 +373,7 @@ class CartographySelector():
         and finally appends the new element at the last index.
         """
         self._contents = (self._contents[:n]
-                          + self._contents[n+1:]
+                          + self._contents[n + 1:]
                           + [new_element])
 
     def prepend(self, new_element):
@@ -419,8 +415,8 @@ class CartographySelector():
         max_index = self.__len__() // 2 - 1
         self.mirror(random.randint(0, max_index))
 
-    def randomise(self):
-        r'Randomises the position of the elements of ``contents``.'
+    def shuffle(self):
+        r'Shuffles the position of the elements of ``contents``.'
         random.shuffle(self._contents)
 
     ### PRIVATE METHODS ###
@@ -429,9 +425,9 @@ class CartographySelector():
         r"""Given a decay rate, this method generates the weights of individual
         indeces.
         """
-        self.weights = []
+        self._weights = []
         for n in range(self.__len__()):
-            self.weights.append(self._decay_rate ** n)
+            self._weights.append(self._decay_rate ** n)
 
     ### PUBLIC PROPERTIES ###
 
@@ -463,7 +459,8 @@ class CartographySelector():
 
     @decay_rate.setter
     def decay_rate(self,
-                   decay_rate: float):
+                   decay_rate: float,
+                   ):
         if not isinstance(decay_rate, float):
             raise TypeError("'decay_rate' must be float")
         if decay_rate <= 0.0 or decay_rate > 1.0:
@@ -473,13 +470,21 @@ class CartographySelector():
         self._generate_weights()
 
     @property
-    def previous_index(self):
+    def previous_index(self) -> Union[int, None]:
         r"""Read-only property, returns the index of the previously output
         element.
         """
         return self._previous_index
 
     @property
-    def previous_result(self):
+    def previous_result(self) -> Any:
         r'Read-only property, returns the previously output element.'
-        return self._contents[self._previous_index]
+        if self._previous_index is not None:
+            return self._contents[self._previous_index]
+        else:
+            return self._previous_index
+
+    @property
+    def weights(self) -> list:
+        r'Read-only property, returns the weight vector.'
+        return self._weights
