@@ -1,37 +1,35 @@
 import random
+from typing import Any, Optional, Union
 
 
 class TenneySelector():
-    r"""This in an implementation of the Dissonant Counterpoint Algorithm by
-    James Tenney. This class can be used to randomly select elements from an
-    input list, giving more weight to elements which have not been selected in
-    recent iterations. In other words, Tenney's algorithm uses feedback in
-    order to lower the weight of recently selected elements.
+    r"""``TenneySelector`` is an implementation of the Dissonant Counterpoint
+    Algorithm by James Tenney. This class can be used to randomly select
+    elements from an input list, giving more weight to elements which have not
+    been selected in recent iterations. In other words, Tenney's algorithm uses
+    feedback in order to lower the weight of recently selected elements.
 
     This implementation is based on the paper: Polansky, L., A. Barnett, and
     M. Winter (2011). 'A Few More Words About James Tenney: Dissonant
     Counterpoint and Statistical Feedback'. In: Journal of Mathematics and
     Music 5(2). pp. 63--82.
 
-    ..  container:: example
-
-        The selector should be initialised with a list of objects. The contents
-        of the list can be absolutely anything.
+    Example:
+        The selector should be initialised with a list of objects. The elements
+        of this list can be of any type.
 
         >>> selector = auxjad.TenneySelector(['A', 'B', 'C', 'D', 'E', 'F'])
         >>> selector.contents
         ['A', 'B', 'C', 'D', 'E', 'F']
 
-        Applying the ``len()`` function to the selector will give the length
+        Applying the ``len()`` function to the selector will return the length
         of the input list.
 
         >>> len(selector)
         6
 
         When no other keyword arguments are used, the default probabilities of
-        each element in the list is 1.0. Probabilities are not normalised. Use
-        the previous_index attribute to check the previously selected index
-        (default is None).
+        each element in the list is ``1.0``. Probabilities are not normalised.
 
         >>> selector.probabilities
         [1.0, 1.0, 1.0, 1.0, 1.0, 1.0]
@@ -65,16 +63,32 @@ class TenneySelector():
         From the result above it is possible to see that there are no immediate
         repetitions of elements (since once selected, their probability is
         always set to 0.0 and will take at least one iteration to grow to a
-        non-zero value). Checking the probabilities and previous_index
-        attributes will give us their current values.
+        non-zero value). Checking the ``probabilities`` and ``previous_index``
+        properties will return us their current values.
 
         >>> selector.probabilities
         [6.0, 5.0, 0.0, 3.0, 1.0, 2.0]
         >>> selector.previous_index
         2
 
-    ..  container:: example
+    Example:
+        Use the read-only properties ``previous_result`` and ``previous_index``
+        to output the previous result and its index. Default values for both
+        is ``None``.
 
+        >>> selector = auxjad.TenneySelector(['A', 'B', 'C', 'D', 'E', 'F'])
+        >>> selector.previous_index
+        None
+        >>> selector.previous_result
+        None
+        >>> selector()
+        C
+        >>> selector.previous_index
+        2
+        >>> selector.previous_result
+        C
+
+    Example:
         This class can take two optional keywords argument during its
         instantiation, namely ``weights`` and ``curvature``. ``weights`` takes
         a list of floats with the individual weights of each element; by
@@ -115,8 +129,7 @@ class TenneySelector():
         >>> selector.probabilities
         [2.0, 0.0, 2.0, 2.0, 2.0, 2.0]
 
-    ..  container:: example
-
+    Example:
         Using a convex curvature:
 
         >>> selector = auxjad.TenneySelector(['A', 'B', 'C', 'D', 'E', 'F'],
@@ -163,8 +176,7 @@ class TenneySelector():
         which is why there is a high chance of an element being selected again
         just two iterations apart.
 
-    ..  container:: example
-
+    Example:
         Using a concave curvature:
 
         >>> selector = auxjad.TenneySelector(['A', 'B', 'C', 'D', 'E', 'F'],
@@ -211,8 +223,7 @@ class TenneySelector():
         curvature, the higher the difference between these values, making some
         of them much more likely to be selected.
 
-    ..  container:: example
-
+    Example:
         Each element can also have a fixed weight to themselves. This will
         affect the probability calculation. The example below uses the default
         linear curvature.
@@ -235,8 +246,7 @@ class TenneySelector():
         >>> selector.probabilities
         [7.0, 12.0, 10.0, 15.0, 0.0, 20.0]
 
-    ..  container:: example
-
+    Example:
         To reset the probability distribution of all elements to its initial
         value (an uniform distribution), use the method
         ``reset_probabilities()``.
@@ -250,8 +260,7 @@ class TenneySelector():
         >>> selector.probabilities
         [1.0, 1.0, 1.0, 1.0, 1.0, 1.0]
 
-    ..  container:: example
-
+    Example:
         The ``contents`` of instances of this class can be indexed and sliced.
         This allows reading, assigning, or deleting values from ``contents``.
         Replacing elements by assignment will not affect the ``probabilities``
@@ -290,8 +299,7 @@ class TenneySelector():
         >>> 'A' in selector
         False
 
-    ..  container:: example
-
+    Example:
         A new list of an arbitrary length can be set at any point using the
         property ``contents``. Do notice that both ``probabilities`` and
         ``weights`` will be reset at that point.
@@ -320,8 +328,7 @@ class TenneySelector():
         >>> selector.probabilities
         [1.0, 1.0, 1.0, 1.0]
 
-    ..  container:: example
-
+    Example:
         To change the curvature value at any point, simply set the property
         ``curvature`` to a different value.
 
@@ -333,18 +340,28 @@ class TenneySelector():
         0.25
     """
 
+    ### CLASS VARIABLES ###
+
+    __slots__ = ('_contents',
+                 '_weights',
+                 '_curvature',
+                 '_counter',
+                 '_previous_index',
+                 '_probabilities',
+                 )
+
     ### INITIALISER ###
 
     def __init__(self,
                  contents: list,
                  *,
-                 weights: list = None,
+                 weights: Optional[list] = None,
                  curvature: float = 1.0,
                  ):
         r'Initialises self.'
         if not isinstance(contents, list):
             raise TypeError("'contents' must be 'list'")
-        if weights:
+        if weights is not None:
             if not isinstance(weights, list):
                 raise TypeError("'weights' must be 'list'")
             if not len(contents) == len(weights):
@@ -360,7 +377,7 @@ class TenneySelector():
             raise ValueError("'curvature' must be larger than 0.0")
 
         self._contents = contents[:]
-        if weights:
+        if weights is not None:
             self._weights = weights[:]
         else:
             self._weights = [1.0 for _ in range(self.__len__())]
@@ -383,8 +400,8 @@ class TenneySelector():
         r'Calls the selection process and outputs one element of ``contents``.'
         self._previous_index = random.choices(
             [n for n in range(self.__len__())],
-            weights=self.probabilities,
-            )[0]
+            weights=self._probabilities,
+        )[0]
         self._regenerate_counts()
         self._generate_probabilities()
         return self._contents[self._previous_index]
@@ -410,8 +427,8 @@ class TenneySelector():
         slicing.
         """
         del self._contents[key]
-        del self.weights[key]
-        del self.probabilities[key]
+        del self._weights[key]
+        del self._probabilities[key]
         del self._counter[key]
 
     ### PUBLIC METHODS ###
@@ -441,11 +458,13 @@ class TenneySelector():
         r"""Generates the probabilities given the weights of the elements as
         well as their count numbers (which are fed into the growth function).
         """
+        if not isinstance(reset, bool):
+            raise TypeError("'reset' must be 'bool")
         if reset:
             self._counter = [1 for _ in range(self.__len__())]
-        self.probabilities = []
+        self._probabilities = []
         for weight, count in zip(self._weights, self._counter):
-            self.probabilities.append(weight * self._growth_function(count))
+            self._probabilities.append(weight * self._growth_function(count))
 
     def _growth_function(self, count):
         r'Applies the growth exponent given a number of counts.'
@@ -465,7 +484,8 @@ class TenneySelector():
         if not isinstance(contents, list):
             raise TypeError("'contents' must be 'list")
         self._contents = contents[:]
-        self.weights = [1.0 for _ in range(self.__len__())]
+        self._weights = [1.0 for _ in range(self.__len__())]
+        self._generate_probabilities(reset=True)
 
     @property
     def weights(self) -> list:
@@ -479,17 +499,16 @@ class TenneySelector():
         if not isinstance(weights, list):
             raise TypeError("'weights' must be 'list'")
         if not self.__len__() == len(weights):
-            raise ValueError("'weights' must have the same length "
-                             "as the contents of the object")
+            raise ValueError("'weights' must have the same length as the "
+                             "contents of the object")
         if not all(isinstance(weight, (int, float))
                    for weight in weights):
-            raise TypeError("'weights' elements must be "
-                            "'int' or 'float'")
+            raise TypeError("'weights' elements must be 'int' or 'float'")
         self._weights = weights[:]
         self._generate_probabilities(reset=True)
 
     @property
-    def curvature(self) -> list:
+    def curvature(self) -> float:
         r'The exponent of the growth function.'
         return self._curvature
 
@@ -505,8 +524,21 @@ class TenneySelector():
         self._generate_probabilities()
 
     @property
-    def previous_index(self):
+    def previous_index(self) -> Union[int, None]:
         r"""Read-only property, returns the index of the previously output
         element.
         """
         return self._previous_index
+
+    @property
+    def previous_result(self) -> Any:
+        r'Read-only property, returns the previously output element.'
+        if self._previous_index is not None:
+            return self._contents[self._previous_index]
+        else:
+            return self._previous_index
+
+    @property
+    def probabilities(self) -> list:
+        r'Read-only property, returns the probabilities vector.'
+        return self._probabilities
