@@ -1,7 +1,13 @@
 import copy
 import random
+from typing import Union
+
 import abjad
+
 from ..utilities.leaves_are_tieable import leaves_are_tieable
+from ..utilities.remove_repeated_time_signatures import (
+    remove_repeated_time_signatures,
+)
 
 
 class _LoopParent():
@@ -10,6 +16,20 @@ class _LoopParent():
     methods.
     """
 
+    ### CLASS VARIABLES ###
+
+    __slots__ = ('_contents',
+                 '_head_position',
+                 '_window_size',
+                 '_step_size',
+                 '_max_steps',
+                 '_repetition_chance',
+                 '_forward_bias',
+                 '_current_window',
+                 '_is_first_window',
+                 '_processs_on_first_call',
+                 )
+
     ### INITIALISER ###
 
     def __init__(self,
@@ -19,18 +39,20 @@ class _LoopParent():
                  max_steps,
                  repetition_chance,
                  forward_bias,
-                 move_window_on_first_call,
+                 processs_on_first_call,
                  ):
         r'Initialises self.'
-        if not isinstance(move_window_on_first_call, bool):
-            raise TypeError("'move_window_on_first_call' must be 'bool'")
+        if not isinstance(processs_on_first_call, bool):
+            raise TypeError("'processs_on_first_call' must be 'bool'")
         self.head_position = head_position
         self.window_size = window_size
         self.step_size = step_size
         self.max_steps = max_steps
         self.repetition_chance = repetition_chance
         self.forward_bias = forward_bias
-        self._is_first_window = not move_window_on_first_call
+        self.processs_on_first_call = processs_on_first_call
+        self._is_first_window = True
+        self._current_window = None
 
     ### SPECIAL METHODS ###
 
@@ -52,7 +74,7 @@ class _LoopParent():
         if self._done:
             raise StopIteration
         self._slice_contents()
-        return self._current_window
+        return self.current_window
 
     def __iter__(self):
         r'Returns an iterator, allowing instances to be used as iterators.'
@@ -76,16 +98,17 @@ class _LoopParent():
                     dummy_container.append(self.__call__())
                 else:
                     new_window = self.__call__()
-                    leaf1 = abjad.select(new_window).leaves()[0]
-                    leaf2 = abjad.select(dummy_container).leaves()[-1]
+                    leaf1 = abjad.select(new_window).leaf(0)
+                    leaf2 = abjad.select(dummy_container).leaf(-1)
                     if leaves_are_tieable(leaf1, leaf2):
                         abjad.attach(abjad.Tie(), dummy_container[-1])
                     dummy_container.append(new_window)
             except RuntimeError:
                 break
-        result = dummy_container[:]
+        remove_repeated_time_signatures(dummy_container)
+        output = dummy_container[:]
         dummy_container[:] = []
-        return result
+        return output
 
     def output_n(self,
                  n: int,
@@ -108,40 +131,43 @@ class _LoopParent():
                 dummy_container.append(self.__call__())
             else:
                 new_window = self.__call__()
-                leaf1 = abjad.select(new_window).leaves()[0]
-                leaf2 = abjad.select(dummy_container).leaves()[-1]
+                leaf1 = abjad.select(new_window).leaf(0)
+                leaf2 = abjad.select(dummy_container).leaf(-1)
                 if leaves_are_tieable(leaf1, leaf2):
                     abjad.attach(abjad.Tie(), dummy_container[-1])
                 dummy_container.append(new_window)
-        result = dummy_container[:]
+        remove_repeated_time_signatures(dummy_container)
+        output = dummy_container[:]
         dummy_container[:] = []
-        return result
+        return output
 
     ### PRIVATE METHODS ###
 
     def _move_head(self):
         r"""Moves the head by a certain number of steps of fixed size, either
-        forwards or backwards according to the forward bias
+        forwards or backwards according to the forward bias.
         """
-        if not self._is_first_window:  # 1st window always at initial position
+        if not self._is_first_window or self._processs_on_first_call:
             if (self._repetition_chance == 0.0
                     or random.random() > self._repetition_chance):
                 step = self._step_size * random.randint(1, self._max_steps)
                 diretion = self._biased_choice(self._forward_bias)
                 self._head_position += step * diretion
-        else:
-            self._is_first_window = False
+        self._is_first_window = False
 
     def _slice_contents(self):
+        r'Will be defined for each individual child class.'
         pass
 
     @staticmethod
     def _biased_choice(bias):
-        return random.choices([1, -1], weights=[bias, 1.0-bias])[0]
+        r'Returns either +1 or -1 according to a bias value.'
+        return random.choices([1, -1], weights=[bias, 1.0 - bias])[0]
 
     @staticmethod
-    def _remove_all_time_signatures(contents):
-        for leaf in abjad.select(contents).leaves():
+    def _remove_all_time_signatures(container):
+        r'Removes all time signatures of an ``abjad.Container``'
+        for leaf in abjad.select(container).leaves():
             if abjad.inspect(leaf).effective(abjad.TimeSignature):
                 abjad.detach(abjad.TimeSignature, leaf)
 
@@ -160,7 +186,7 @@ class _LoopParent():
             raise TypeError("'head_position' must be 'int'")
         if head_position < 0:
             raise ValueError("'head_position' must be a positive 'int'")
-        if head_position >= self._contents.__len__():
+        if head_position >= self.__len__():
             raise ValueError("'head_position' must be smaller than the length "
                              "of 'contents'")
         self._is_first_window = True
@@ -179,7 +205,7 @@ class _LoopParent():
             raise TypeError("'window_size' must be 'int'")
         if window_size < 1:
             raise ValueError("'window_size' must be greater than zero")
-        if window_size > self._contents.__len__():
+        if window_size > self.__len__():
             raise ValueError("'window_size' must be smaller than or equal to "
                              "the length of 'contents'")
         self._window_size = window_size
@@ -197,7 +223,7 @@ class _LoopParent():
             raise TypeError("'step_size' must be 'int'")
         if step_size < 1:
             raise ValueError("'step_size' must be greater than zero")
-        if step_size >= self._contents.__len__():
+        if step_size >= self.__len__():
             raise ValueError("'step_size' must be smaller than the length of "
                              "'contents'")
         self._step_size = step_size
@@ -252,11 +278,29 @@ class _LoopParent():
         self._forward_bias = forward_bias
 
     @property
-    def current_window(self) -> (list, abjad.Selection):
-        r"""Read-only property, returns the window at the current head
-        position.
+    def processs_on_first_call(self) -> bool:
+        r"""If ``True`` then the ``contents`` will be processed in the very
+        first call.
         """
-        return copy.deepcopy(self._current_window)
+        return self._processs_on_first_call
+
+    @processs_on_first_call.setter
+    def processs_on_first_call(self,
+                               processs_on_first_call: bool,
+                               ):
+        if not isinstance(processs_on_first_call, bool):
+            raise TypeError("'processs_on_first_call' must be 'bool'")
+        self._processs_on_first_call = processs_on_first_call
+
+    @property
+    def current_window(self) -> Union[abjad.Selection, None]:
+        r'Read-only property, returns the window at the current head position.'
+        if self._current_window is None:
+            return self._current_window
+        current_window = copy.deepcopy(self._current_window)
+        if self._omit_time_signatures:
+            self._remove_all_time_signatures(current_window)
+        return current_window
 
     ### PRIVATE PROPERTIES ###
 
@@ -265,5 +309,5 @@ class _LoopParent():
         r"""Boolean indicating whether the process is done (i.e. whether the
         head position has overtaken the ``contents`` length).
         """
-        return (self._head_position >= self._contents.__len__()
-            or self._head_position < 0)
+        return (self._head_position >= self.__len__()
+                or self._head_position < 0)
