@@ -1,4 +1,7 @@
+from typing import Optional, Union
+
 import abjad
+
 from ._HarmonicParent import _HarmonicParent
 
 
@@ -6,8 +9,7 @@ class ArtificialHarmonic(abjad.Chord, _HarmonicParent):
     r"""Creates a chord with a tweaked top note head for notating artificial
     harmonics. This is a child class of ``abjad.Chord``.
 
-    ..  container:: example
-
+    Example:
         Usage is similar to ``abjad.Chord``:
 
         >>> harm = auxjad.ArtificialHarmonic("<g c'>4")
@@ -26,7 +28,7 @@ class ArtificialHarmonic(abjad.Chord, _HarmonicParent):
         many different ways:
 
         >>> harm1 = auxjad.ArtificialHarmonic("<g c'>4")
-        >>> harm2 = auxjad.ArtificialHarmonic(["g", "c'"], 1/4)
+        >>> harm2 = auxjad.ArtificialHarmonic(["g", "c'"], 1 / 4)
         >>> harm3 = auxjad.ArtificialHarmonic([-5, 0], 0.25)
         >>> harm4 = auxjad.ArtificialHarmonic([-5, 0], abjad.Duration(1, 4))
         >>> staff = abjad.Staff([harm1, harm2, harm3, harm4])
@@ -59,8 +61,7 @@ class ArtificialHarmonic(abjad.Chord, _HarmonicParent):
 
 
 
-    ..  container:: example
-
+    Example:
         It is important to note that this class can only be initialised with
         exactly two pitches. Any other number of pitches will raise a
         ``ValueError``:
@@ -69,8 +70,7 @@ class ArtificialHarmonic(abjad.Chord, _HarmonicParent):
         ValueError: 'ArtificialHarmonic' requires exactly two 'note_heads' for
         initialisation
 
-    ..  container:: example
-
+    Example:
         When creating an ``ArtificialHarmonic``, use the keyword argument
         ``style`` to set a different type of note head for the top note, such
         as ``'harmonic-mixed'``:
@@ -89,8 +89,7 @@ class ArtificialHarmonic(abjad.Chord, _HarmonicParent):
 
         .. figure:: ../_images/image-ArtificialHarmonic-3.png
 
-    ..  container:: example
-
+    Example:
         To notate natural harmonics with a parenthesised pitch for the open
         string at the bottom of the interval, set the keyword
         ``is_parenthesized`` to ``True``.
@@ -111,8 +110,7 @@ class ArtificialHarmonic(abjad.Chord, _HarmonicParent):
 
         .. figure:: ../_images/image-ArtificialHarmonic-4.png
 
-    ..  container:: example
-
+    Example:
         Similarly to ``abjad.Chord``, ``ArtificialHarmonic`` can take
         multipliers:
 
@@ -130,8 +128,7 @@ class ArtificialHarmonic(abjad.Chord, _HarmonicParent):
 
         .. figure:: ../_images/image-ArtificialHarmonic-5.png
 
-    ..  container:: example
-
+    Example:
         All properties of ``abjad.Chord`` are also available to be read. This
         class also includes two new properties named ``style`` and
         ``is_parenthesized``:
@@ -162,8 +159,7 @@ class ArtificialHarmonic(abjad.Chord, _HarmonicParent):
         >>> harm.is_parenthesized
         True
 
-    ..  container:: example
-
+    Example:
         The methods ``sounding_pitch()`` and ``sounding_note()`` return the
         sounding pitch and sounding note, respectively. Their types are
         ``abjad.Pitch`` and ``abjad.Note``, respectively.
@@ -189,8 +185,7 @@ class ArtificialHarmonic(abjad.Chord, _HarmonicParent):
         b''4
         g'4
 
-    ..  container:: example
-
+    Example:
         To add a markup expression to the artificial harmonic, use the
         ``markup`` optional keyword argument, which takes strings. By default,
         the markup position is above the harmonic note, but this can be
@@ -244,10 +239,10 @@ class ArtificialHarmonic(abjad.Chord, _HarmonicParent):
 
         .. figure:: ../_images/image-ArtificialHarmonic-7.png
 
-    ..  warning::
+    ..  error::
 
         If another markup is attached to the harmonic note, trying to set the
-        ``markup`` to ``None`` will raise an Exception:
+        ``markup`` to ``None`` will raise an exception:
 
         >>> harm = auxjad.ArtificialHarmonic("<a d'>1")
         >>> abjad.attach(abjad.Markup('test'), harm)
@@ -255,8 +250,7 @@ class ArtificialHarmonic(abjad.Chord, _HarmonicParent):
         >>> harm.markup = None
         Exception: multiple indicators attached to client.
 
-    ..  container:: example
-
+    Example:
         The note created by ``sounding_note()`` inherits all indicators from
         the ``ArtificialHarmonic``.
 
@@ -268,7 +262,7 @@ class ArtificialHarmonic(abjad.Chord, _HarmonicParent):
 
         .. figure:: ../_images/image-ArtificialHarmonic-8.png
 
-    ..  warning::
+    ..  error::
 
         Both ``sounding_pitch()`` and ``sounding_note()`` methods raise a
         ValueError exception when it cannot calculate the sounding pitch for
@@ -280,20 +274,28 @@ class ArtificialHarmonic(abjad.Chord, _HarmonicParent):
         ValueError: cannot calculate sounding pitch for given interval
     """
 
+    ### CLASS VARIABLES ###
+
+    __slots__ = ('_style',
+                 '_is_parenthesized',
+                 '_direction',
+                 '_markup',
+                 )
+
     ### INITIALISER ###
 
     def __init__(self,
                  *arguments,
-                 multiplier: abjad.typings.DurationTyping = None,
-                 tag: abjad.Tag = None,
+                 multiplier: Optional[abjad.typings.DurationTyping] = None,
+                 tag: Optional[abjad.Tag] = None,
                  style: str = 'harmonic',
                  is_parenthesized: bool = False,
-                 markup: str = None,
-                 direction: (str, abjad.enums.VerticalAlignment) = 'up',
+                 markup: Optional[str] = None,
+                 direction: Union[str, abjad.enums.VerticalAlignment] = 'up',
                  ):
         r'Initialises self.'
         super().__init__(*arguments, multiplier=multiplier, tag=tag)
-        if len(self.note_heads) != 2:
+        if len(self._note_heads) != 2:
             raise ValueError("'ArtificialHarmonic' requires exactly two "
                              "'note_heads' for initialisation")
         self.style = style
@@ -305,8 +307,8 @@ class ArtificialHarmonic(abjad.Chord, _HarmonicParent):
 
     def sounding_pitch(self) -> abjad.Pitch:
         r'Returns the sounding pitch of the harmonic as an ``abjad.Pitch``.'
-        interval = abs(self.note_heads[1].written_pitch
-                       - self.note_heads[0].written_pitch).semitones
+        interval = abs(self._note_heads[1].written_pitch
+                       - self._note_heads[0].written_pitch).semitones
         sounding_pitch_dict = {1: 48,
                                2: 36,
                                3: 31,
@@ -321,7 +323,7 @@ class ArtificialHarmonic(abjad.Chord, _HarmonicParent):
                                28: 28,
                                }
         try:
-            sounding_pitch = (self.note_heads[0].written_pitch
+            sounding_pitch = (self._note_heads[0].written_pitch
                               + sounding_pitch_dict[interval])
         except KeyError as err:
             raise ValueError('cannot calculate sounding pitch for given '
@@ -330,7 +332,7 @@ class ArtificialHarmonic(abjad.Chord, _HarmonicParent):
 
     def sounding_note(self) -> abjad.Note:
         r'Returns the sounding note of the harmonic as an ``abjad.Note``.'
-        note = abjad.Note(self.sounding_pitch(), self.written_duration)
+        note = abjad.Note(self.sounding_pitch(), self._written_duration)
         for indicator in abjad.inspect(self).indicators():
             abjad.attach(indicator, note)
         return note
@@ -341,7 +343,7 @@ class ArtificialHarmonic(abjad.Chord, _HarmonicParent):
     def written_pitches(self) -> abjad.pitch.PitchSegment:
         r'The written pitches of the two note heads.'
         return abjad.pitch.PitchSegment(
-            items=(note_head.written_pitch for note_head in self.note_heads),
+            items=(note_head.written_pitch for note_head in self._note_heads),
             item_class=abjad.pitch.NamedPitch,
         )
 
@@ -354,7 +356,7 @@ class ArtificialHarmonic(abjad.Chord, _HarmonicParent):
             raise ValueError("'ArtificialHarmonic' requires exactly two "
                              "pitches")
         for i, pitch in enumerate(written_pitches_):
-            self.note_heads[i].written_pitch = pitch
+            self._note_heads[i].written_pitch = pitch
 
     @property
     def style(self) -> str:
@@ -368,7 +370,7 @@ class ArtificialHarmonic(abjad.Chord, _HarmonicParent):
         if not isinstance(style, str):
             raise TypeError("'style' must be 'str'")
         self._style = style
-        abjad.tweak(self.note_heads[1]).style = self._style
+        abjad.tweak(self._note_heads[1]).style = self._style
 
     @property
     def is_parenthesized(self) -> bool:
@@ -382,6 +384,6 @@ class ArtificialHarmonic(abjad.Chord, _HarmonicParent):
         if not isinstance(is_parenthesized, bool):
             raise TypeError("'is_parenthesized' must be 'bool'")
         self._is_parenthesized = is_parenthesized
-        self.note_heads[0].is_parenthesized = self._is_parenthesized
+        self._note_heads[0].is_parenthesized = self._is_parenthesized
         if self._is_parenthesized:
-            abjad.tweak(self.note_heads[0]).ParenthesesItem__font_size = -4
+            abjad.tweak(self._note_heads[0]).ParenthesesItem__font_size = -4
