@@ -1,4 +1,7 @@
+from typing import Optional, Union
+
 import abjad
+
 from ._HarmonicParent import _HarmonicParent
 
 
@@ -6,8 +9,7 @@ class HarmonicNote(abjad.Note, _HarmonicParent):
     r"""Creates a note with tweaked notehead for harmonics. This is a child
     class of ``abjad.Note``.
 
-    ..  container:: example
-
+    Example:
         Usage is similar to ``abjad.Note``:
 
         >>> harm = auxjad.HarmonicNote("c''4")
@@ -23,7 +25,7 @@ class HarmonicNote(abjad.Note, _HarmonicParent):
         many different ways:
 
         >>> harm1 = auxjad.HarmonicNote("c''4")
-        >>> harm2 = auxjad.HarmonicNote("c''", 1/4)
+        >>> harm2 = auxjad.HarmonicNote("c''", 1 / 4)
         >>> harm3 = auxjad.HarmonicNote(12, 0.25)
         >>> harm4 = auxjad.HarmonicNote(12, abjad.Duration(1, 4))
         >>> staff = abjad.Staff([harm1, harm2, harm3, harm4])
@@ -42,8 +44,7 @@ class HarmonicNote(abjad.Note, _HarmonicParent):
 
         .. figure:: ../_images/image-HarmonicNote-2.png
 
-    ..  container:: example
-
+    Example:
         When creating an ``HarmonicNote``, use the keyword argument ``style``
         to set a different type of note head, such as ``'harmonic-mixed'``:
 
@@ -58,8 +59,7 @@ class HarmonicNote(abjad.Note, _HarmonicParent):
 
         .. figure:: ../_images/image-HarmonicNote-3.png
 
-    ..  container:: example
-
+    Example:
         Similarly to ``abjad.Note``, ``HarmonicNote`` can take multipliers:
 
         >>> harm = auxjad.HarmonicNote("c''4",
@@ -73,8 +73,7 @@ class HarmonicNote(abjad.Note, _HarmonicParent):
 
         .. figure:: ../_images/image-HarmonicNote-4.png
 
-    ..  container:: example
-
+    Example:
         All properties of ``abjad.Note`` are also available to be read. This
         class also includes a new property named ``style``:
 
@@ -99,8 +98,7 @@ class HarmonicNote(abjad.Note, _HarmonicParent):
         >>> harm.style
         'harmonic-mixed'
 
-    ..  container:: example
-
+    Example:
         To create a harmonic note with a regular note head and with a flageolet
         circle above it, use the style ``'flageolet'``:
 
@@ -115,8 +113,7 @@ class HarmonicNote(abjad.Note, _HarmonicParent):
 
         .. figure:: ../_images/image-HarmonicNote-5.png
 
-    ..  container:: example
-
+    Example:
         To add a markup expression to the harmonic note, use the ``markup``
         optional keyword argument, which takes strings. By default, the markup
         position is above the harmonic note, but this can be overridden using
@@ -158,10 +155,10 @@ class HarmonicNote(abjad.Note, _HarmonicParent):
 
         .. figure:: ../_images/image-HarmonicNote-7.png
 
-    ..  warning::
+    ..  error::
 
         If another markup is attached to the harmonic note, trying to set the
-        ``markup`` to ``None`` will raise an Exception:
+        ``markup`` to ``None`` will raise an exception:
 
         >>> harm = auxjad.HarmonicNote("d''1")
         >>> abjad.attach(abjad.Markup('test'), harm)
@@ -170,15 +167,22 @@ class HarmonicNote(abjad.Note, _HarmonicParent):
         Exception: multiple indicators attached to client.
     """
 
+    ### CLASS VARIABLES ###
+
+    __slots__ = ('_style',
+                 '_direction',
+                 '_markup',
+                 )
+
     ### INITIALISER ###
 
     def __init__(self,
                  *arguments,
-                 multiplier: abjad.typings.DurationTyping = None,
-                 tag: abjad.Tag = None,
+                 multiplier: Optional[abjad.typings.DurationTyping] = None,
+                 tag: Optional[abjad.Tag] = None,
                  style: str = 'harmonic',
-                 markup: str = None,
-                 direction: (str, abjad.enums.VerticalAlignment) = 'up',
+                 markup: Optional[str] = None,
+                 direction: Union[str, abjad.enums.VerticalAlignment] = 'up',
                  ):
         r'Initialises self.'
         super().__init__(*arguments, multiplier=multiplier, tag=tag)
@@ -201,7 +205,7 @@ class HarmonicNote(abjad.Note, _HarmonicParent):
             raise TypeError("'style' must be 'str'")
         self._style = style
         if not self._style == 'flageolet':
-            abjad.tweak(self.note_head).style = self._style
+            abjad.tweak(self._note_head).style = self._style
         else:
             flageolet = abjad.LilyPondLiteral(r'\flageolet',
                                               format_slot='after',
