@@ -1,22 +1,24 @@
+from typing import Union
+
 import abjad
 
 
-def simplified_time_signature_ratio(ratio: (tuple,
-                                            abjad.TimeSignature,
-                                            abjad.Duration,
-                                            abjad.Meter,
-                                            ),
+def simplified_time_signature_ratio(ratio: Union[tuple,
+                                                 abjad.TimeSignature,
+                                                 abjad.Duration,
+                                                 abjad.Meter,
+                                                 ],
                                     *,
                                     min_denominator: int = 4,
                                     output_pair_of_int: bool = False,
-                                    ) -> (abjad.TimeSignature, tuple):
+                                    ) -> Union[abjad.TimeSignature, tuple]:
     r"""Returns an ``abjad.TimeSignature`` with the simplified ratio of an
     input ratio according to a minimum denominator value. The input ratio can
-    be a ``tuple`` of integers, an ``abjad.TimeSignature``, ``abjad.Duration``,
-    or an ``abjad.Meter``).
-
-    ..  container:: example
+    be an ``abjad.TimeSignature``, ``abjad.Duration``, an ``abjad.Meter``, or a
+    ``tuple`` of integers. If the input is a ``tuple``, the return value is
+    also a ``tuple``.
 
+    Example:
         By default, the function simplifies the ratio of numerator/denominator
         using a minimum denominator value of 4 (that is, the denominator will
         not get smaller than 4). In the case below, (2, 4) is the simplest
@@ -53,8 +55,7 @@ def simplified_time_signature_ratio(ratio: (tuple,
         >>> format(time_signature)
         abjad.TimeSignature((1, 1))
 
-    ..  container:: example
-
+    Example:
         By default, the function returns an ``abjad.TimeSignature`` for
         whatever type of argument it receives (which can be a ``tuple`` of
         integers, an ``abjad.TimeSignature``, an ``abjad.Duration``, or an
@@ -115,10 +116,10 @@ def simplified_time_signature_ratio(ratio: (tuple,
         >>> pair
         (2, 4)
     """
-    if not isinstance(ratio, (tuple, abjad.TimeSignature,
-                              abjad.Duration, abjad.Meter)):
-        raise TypeError("argument must be 'tuple', 'abjad.Duration', or "
-                        "'abjad.TimeSignature'")
+    if not isinstance(ratio, (tuple, abjad.TimeSignature, abjad.Duration,
+                              abjad.Meter)):
+        raise TypeError("argument must be 'tuple', 'abjad.Duration', "
+                        "'abjad.TimeSignature',  or 'abjad.Meter'")
     if not isinstance(min_denominator, int):
         raise TypeError("'min_denominator' must be 'int'")
     if not isinstance(output_pair_of_int, bool):
