@@ -1,5 +1,6 @@
 import abjad
 import pytest
+
 import auxjad
 
 
@@ -18,7 +19,7 @@ def test_ArtificialHarmonic_01():
 
 def test_ArtificialHarmonic_02():
     harm1 = auxjad.ArtificialHarmonic("<g c'>4")
-    harm2 = auxjad.ArtificialHarmonic(["g", "c'"], 1/4)
+    harm2 = auxjad.ArtificialHarmonic(["g", "c'"], 1 / 4)
     harm3 = auxjad.ArtificialHarmonic([-5, 0], 0.25)
     harm4 = auxjad.ArtificialHarmonic([-5, 0], abjad.Duration(1, 4))
     harms = [harm1, harm2, harm3, harm4]
@@ -83,7 +84,7 @@ def test_ArtificialHarmonic_05():
 def test_ArtificialHarmonic_06():
     harm = auxjad.ArtificialHarmonic("<g c'>4")
     assert harm.written_pitches == abjad.PitchSegment("g c'")
-    assert harm.written_duration == 1/4
+    assert harm.written_duration == 1 / 4
     assert harm.style == 'harmonic'
     assert not harm.is_parenthesized
     harm.written_pitches = [-5, 2]
@@ -91,7 +92,7 @@ def test_ArtificialHarmonic_06():
     harm.style = 'harmonic-mixed'
     harm.is_parenthesized = True
     assert harm.written_pitches == abjad.PitchSegment("g d'")
-    assert harm.written_duration == 1/8
+    assert harm.written_duration == 1 / 8
     assert harm.style == 'harmonic-mixed'
     assert harm.is_parenthesized
 
@@ -174,7 +175,6 @@ def test_ArtificialHarmonic_14():
                                       markup='I.',
                                       direction=abjad.Down)
     staff = abjad.Staff([harm1, harm2, harm3])
-    abjad.f(staff)
     assert format(staff) == abjad.String.normalize(
         r"""
         \new Staff
@@ -221,3 +221,30 @@ def test_ArtificialHarmonic_16():
     harm.markup = 'I.'
     with pytest.raises(Exception):
         harm.markup = None
+
+
+def test_ArtificialHarmonic_17():
+    harm = auxjad.ArtificialHarmonic("<a d'>1",
+                                     markup='I.',
+                                     direction=abjad.Down)
+    assert harm.direction is abjad.Down
+    assert format(harm) == abjad.String.normalize(
+        r"""
+        <
+            a
+            \tweak style #'harmonic
+            d'
+        >1
+        _ \markup { I. }
+        """)
+    harm.direction = abjad.Up
+    assert harm.direction is abjad.Up
+    assert format(harm) == abjad.String.normalize(
+        r"""
+        <
+            a
+            \tweak style #'harmonic
+            d'
+        >1
+        ^ \markup { I. }
+        """)
