@@ -1,5 +1,6 @@
 import abjad
 import pytest
+
 import auxjad
 
 
@@ -15,7 +16,7 @@ def test_HarmonicNote_01():
 
 def test_HarmonicNote_02():
     harm1 = auxjad.HarmonicNote("c''4")
-    harm2 = auxjad.HarmonicNote("c''", 1/4)
+    harm2 = auxjad.HarmonicNote("c''", 1 / 4)
     harm3 = auxjad.HarmonicNote(12, 0.25)
     harm4 = auxjad.HarmonicNote(12, abjad.Duration(1, 4))
     harms = [harm1, harm2, harm3, harm4]
@@ -54,13 +55,13 @@ def test_HarmonicNote_04():
 def test_HarmonicNote_05():
     harm = auxjad.HarmonicNote("c''4")
     assert harm.written_pitch == "c''"
-    assert harm.written_duration == 1/4
+    assert harm.written_duration == 1 / 4
     assert harm.style == 'harmonic'
     harm.written_pitch = 18
     harm.written_duration = abjad.Duration(1, 8)
     harm.style = 'harmonic-mixed'
     assert harm.written_pitch == "fs''"
-    assert harm.written_duration == 1/8
+    assert harm.written_duration == 1 / 8
     assert harm.style == 'harmonic-mixed'
 
 
@@ -119,3 +120,24 @@ def test_HarmonicNote_09():
     harm.markup = 'III.'
     with pytest.raises(Exception):
         harm.markup = None
+
+
+def test_HarmonicNote_10():
+    harm = auxjad.HarmonicNote("d''1",
+                               markup='III.',
+                               direction=abjad.Down)
+    assert harm.direction is abjad.Down
+    assert format(harm) == abjad.String.normalize(
+        r"""
+        \tweak style #'harmonic
+        d''1
+        _ \markup { III. }
+        """)
+    harm.direction = abjad.Up
+    assert harm.direction is abjad.Up
+    assert format(harm) == abjad.String.normalize(
+        r"""
+        \tweak style #'harmonic
+        d''1
+        ^ \markup { III. }
+        """)
