@@ -1,11 +1,26 @@
+import random
+
 import abjad
 import pytest
+
 import auxjad
 
 
 def test_LoopByWindow_01():
-    input_music = abjad.Container(r"c'4 d'2 e'4 f'2 ~ f'8 g'1")
-    looper = auxjad.LoopByWindow(input_music)
+    container = abjad.Container(r"c'4 d'2 e'4 f'2 ~ f'8 g'1")
+    looper = auxjad.LoopByWindow(container)
+    assert format(looper) == abjad.String.normalize(
+        r"""
+        {
+            c'4
+            d'2
+            e'4
+            f'2
+            ~
+            f'8
+            g'1
+        }
+        """)
     notes = looper()
     staff = abjad.Staff(notes)
     assert format(staff) == abjad.String.normalize(
@@ -24,6 +39,7 @@ def test_LoopByWindow_01():
         r"""
         \new Staff
         {
+            \time 4/4
             c'8.
             d'16
             ~
@@ -40,6 +56,7 @@ def test_LoopByWindow_01():
         r"""
         \new Staff
         {
+            \time 4/4
             c'8.
             d'16
             ~
@@ -53,10 +70,10 @@ def test_LoopByWindow_01():
 
 
 def test_LoopByWindow_02():
-    input_music = abjad.Container(r"c'4 d'2 e'4 f'2 ~ f'8 g'1")
-    looper = auxjad.LoopByWindow(input_music,
+    container = abjad.Container(r"c'4 d'2 e'4 f'2 ~ f'8 g'1")
+    looper = auxjad.LoopByWindow(container,
                                  window_size=(3, 4),
-                                 step_size=(1, 4),
+                                 step_size=(1, 8),
                                  )
     notes = looper()
     staff = abjad.Staff(notes)
@@ -75,15 +92,19 @@ def test_LoopByWindow_02():
         r"""
         \new Staff
         {
-            d'2
-            e'4
+            \time 3/4
+            c'8
+            d'8
+            ~
+            d'4.
+            e'8
         }
         """)
 
 
 def test_LoopByWindow_03():
-    input_music = abjad.Container(r"c'4 d'2 e'4")
-    looper = auxjad.LoopByWindow(input_music,
+    container = abjad.Container(r"c'4 d'2 e'4")
+    looper = auxjad.LoopByWindow(container,
                                  window_size=(3, 4),
                                  step_size=(1, 8),
                                  )
@@ -104,6 +125,7 @@ def test_LoopByWindow_03():
         r"""
         \new Staff
         {
+            \time 3/4
             c'8
             d'8
             ~
@@ -117,6 +139,7 @@ def test_LoopByWindow_03():
         r"""
         \new Staff
         {
+            \time 3/4
             d'2
             e'4
         }
@@ -127,6 +150,7 @@ def test_LoopByWindow_03():
         r"""
         \new Staff
         {
+            \time 3/4
             d'4.
             e'8
             ~
@@ -140,6 +164,7 @@ def test_LoopByWindow_03():
         r"""
         \new Staff
         {
+            \time 3/4
             d'4
             e'4
             r4
@@ -151,6 +176,7 @@ def test_LoopByWindow_03():
         r"""
         \new Staff
         {
+            \time 3/4
             d'8
             e'8
             ~
@@ -164,6 +190,7 @@ def test_LoopByWindow_03():
         r"""
         \new Staff
         {
+            \time 3/4
             e'4
             r2
         }
@@ -174,6 +201,7 @@ def test_LoopByWindow_03():
         r"""
         \new Staff
         {
+            \time 3/4
             e'8
             r8
             r2
@@ -184,15 +212,20 @@ def test_LoopByWindow_03():
 
 
 def test_LoopByWindow_04():
-    input_music = abjad.Container(r"c'4 d'2 e'4 f'2 ~ f'8 g'1")
-    looper = auxjad.LoopByWindow(input_music,
+    container = abjad.Container(r"c'4 d'2 e'4 f'2 ~ f'8 g'1")
+    looper = auxjad.LoopByWindow(container,
                                  window_size=(3, 4),
                                  step_size=(5, 8),
                                  max_steps=2,
                                  repetition_chance=0.25,
                                  forward_bias=0.2,
                                  head_position=(2, 8),
-                                 omit_time_signature=False,
+                                 omit_time_signatures=False,
+                                 fill_with_rests=False,
+                                 boundary_depth=0,
+                                 maximum_dot_count=1,
+                                 rewrite_tuplets=False,
+                                 processs_on_first_call=True,
                                  )
     assert looper.window_size == abjad.Meter((3, 4))
     assert looper.step_size == abjad.Duration((5, 8))
@@ -200,31 +233,46 @@ def test_LoopByWindow_04():
     assert looper.repetition_chance == 0.25
     assert looper.forward_bias == 0.2
     assert looper.head_position == abjad.Duration((1, 4))
-    assert not looper.omit_time_signature
+    assert not looper.omit_time_signatures
+    assert not looper.fill_with_rests
+    assert looper.boundary_depth == 0
+    assert looper.maximum_dot_count == 1
+    assert not looper.rewrite_tuplets
+    assert looper.processs_on_first_call
     looper.window_size = (5, 4)
     looper.step_size = (1, 4)
     looper.max_steps = 3
     looper.repetition_chance = 0.1
     looper.forward_bias = 0.8
     looper.head_position = 0
-    looper.omit_time_signature = True
+    looper.omit_time_signatures = True
+    looper.fill_with_rests = True
+    looper.boundary_depth = 1
+    looper.maximum_dot_count = 2
+    looper.rewrite_tuplets = True
+    looper.processs_on_first_call = False
     assert looper.window_size == abjad.Meter((5, 4))
     assert looper.step_size == abjad.Duration((1, 4))
     assert looper.max_steps == 3
     assert looper.repetition_chance == 0.1
     assert looper.forward_bias == 0.8
     assert looper.head_position == abjad.Duration(0)
-    assert looper.omit_time_signature
+    assert looper.omit_time_signatures
+    assert looper.fill_with_rests
+    assert looper.boundary_depth == 1
+    assert looper.maximum_dot_count == 2
+    assert looper.rewrite_tuplets
+    assert not looper.processs_on_first_call
 
 
 def test_LoopByWindow_05():
-    input_music = abjad.Container(r"c'4 d'4 e'4 f'4")
-    looper = auxjad.LoopByWindow(input_music,
+    container = abjad.Container(r"c'4 d'4 e'4 f'4")
+    looper = auxjad.LoopByWindow(container,
                                  window_size=(3, 4),
                                  step_size=(1, 4),
                                  )
-    music = looper.output_all()
-    staff = abjad.Staff(music)
+    notes = looper.output_all()
+    staff = abjad.Staff(notes)
     assert format(staff) == abjad.String.normalize(
         r"""
         \new Staff
@@ -246,8 +294,8 @@ def test_LoopByWindow_05():
 
 
 def test_LoopByWindow_06():
-    input_music = abjad.Container(r"c'4 d'2 e'4 f'2 ~ f'8 g'1")
-    looper = auxjad.LoopByWindow(input_music)
+    container = abjad.Container(r"c'4 d'2 e'4 f'2 ~ f'8 g'1")
+    looper = auxjad.LoopByWindow(container)
     notes = looper.__next__()
     staff = abjad.Staff(notes)
     assert format(staff) == abjad.String.normalize(
@@ -266,6 +314,7 @@ def test_LoopByWindow_06():
         r"""
         \new Staff
         {
+            \time 4/4
             c'8.
             d'16
             ~
@@ -282,6 +331,7 @@ def test_LoopByWindow_06():
         r"""
         \new Staff
         {
+            \time 4/4
             c'8
             d'8
             ~
@@ -312,6 +362,7 @@ def test_LoopByWindow_06():
         r"""
         \new Staff
         {
+            \time 3/8
             d'4.
         }
         """)
@@ -321,20 +372,20 @@ def test_LoopByWindow_06():
         r"""
         \new Staff
         {
+            \time 3/8
             d'4.
         }
         """)
 
 
 def test_LoopByWindow_07():
-    input_music = abjad.Container(r"\times 2/3 {c'8 d'8 e'} d'2.")
-    looper = auxjad.LoopByWindow(input_music,
+    container = abjad.Container(r"\times 2/3 {c'8 d'8 e'8} d'2.")
+    looper = auxjad.LoopByWindow(container,
                                  window_size=(3, 4),
-                                 step_size=(1, 16))
-    staff = abjad.Staff()
-    for _ in range(3):
-        window = looper()
-        staff.append(window)
+                                 step_size=(1, 16),
+                                 )
+    notes = looper.output_n(3)
+    staff = abjad.Staff(notes)
     assert format(staff) == abjad.String.normalize(
         r"""
         \new Staff
@@ -368,8 +419,8 @@ def test_LoopByWindow_07():
 
 
 def test_LoopByWindow_08():
-    input_music = abjad.Container(r"c'4 d'2 e'4 f'2 ~ f'8 g'1")
-    looper = auxjad.LoopByWindow(input_music, omit_time_signature=True)
+    container = abjad.Container(r"c'4 d'2 e'4 f'2 ~ f'8 g'1")
+    looper = auxjad.LoopByWindow(container, omit_time_signatures=True)
     notes = looper()
     staff = abjad.Staff(notes)
     assert format(staff) == abjad.String.normalize(
@@ -385,30 +436,35 @@ def test_LoopByWindow_08():
 
 def test_LoopByWindow_09():
     wrong_type_input = 'foobar'
-    input_music = abjad.Container(r"c'4 d'2 e'4 f'2 ~ f'8 g'1")
+    container = abjad.Container(r"c'4 d'2 e'4 f'2 ~ f'8 g'1")
     with pytest.raises(TypeError):
         assert auxjad.LoopByWindow(wrong_type_input)
-        assert auxjad.LoopByWindow(input_music, window_size=17j)
-        assert auxjad.LoopByWindow(input_music, max_steps='foobar')
-        assert auxjad.LoopByWindow(input_music, repetition_chance='foobar')
-        assert auxjad.LoopByWindow(input_music, head_position=62.3j)
-        assert auxjad.LoopByWindow(input_music, omit_time_signature='foobar')
+        assert auxjad.LoopByWindow(container, window_size=17j)
+        assert auxjad.LoopByWindow(container, step_size=True)
+        assert auxjad.LoopByWindow(container, max_steps='foo')
+        assert auxjad.LoopByWindow(container, repetition_chance='bar')
+        assert auxjad.LoopByWindow(container, forward_bias=False)
+        assert auxjad.LoopByWindow(container, head_position=62.3j)
+        assert auxjad.LoopByWindow(container, omit_time_signatures='xyz')
+        assert auxjad.LoopByWindow(container, fill_with_rests=1.2)
     with pytest.raises(ValueError):
-        assert auxjad.LoopByWindow(input_music, window_size=(100, 1))
-        assert auxjad.LoopByWindow(input_music, max_steps=-1)
-        assert auxjad.LoopByWindow(input_music, repetition_chance=-0.3)
-        assert auxjad.LoopByWindow(input_music, repetition_chance=1.4)
-        assert auxjad.LoopByWindow(input_music, head_position=(100, 1))
+        assert auxjad.LoopByWindow(container, window_size=(100, 1))
+        assert auxjad.LoopByWindow(container, max_steps=-1)
+        assert auxjad.LoopByWindow(container, repetition_chance=-0.3)
+        assert auxjad.LoopByWindow(container, repetition_chance=1.4)
+        assert auxjad.LoopByWindow(container, forward_bias=-0.3)
+        assert auxjad.LoopByWindow(container, forward_bias=1.4)
+        assert auxjad.LoopByWindow(container, head_position=(100, 1))
 
 
 def test_LoopByWindow_10():
-    input_music = abjad.Container(r"c'4 e'2 d'2 f'4")
-    looper = auxjad.LoopByWindow(input_music,
+    container = abjad.Container(r"c'4 e'2 d'2 f'4")
+    looper = auxjad.LoopByWindow(container,
                                  window_size=(3, 4),
                                  step_size=(1, 4),
                                  )
-    music = looper.output_all(tie_identical_pitches=True)
-    staff = abjad.Staff(music)
+    notes = looper.output_all(tie_identical_pitches=True)
+    staff = abjad.Staff(notes)
     assert format(staff) == abjad.String.normalize(
         r"""
         \new Staff
@@ -434,13 +490,13 @@ def test_LoopByWindow_10():
 
 
 def test_LoopByWindow_11():
-    input_music = abjad.Container(r"c'4 <e' f' g'>2 r4 f'2.")
-    looper = auxjad.LoopByWindow(input_music,
+    container = abjad.Container(r"c'4 <e' f' g'>2 r4 f'2.")
+    looper = auxjad.LoopByWindow(container,
                                  window_size=(3, 4),
                                  step_size=(1, 4),
                                  )
-    music = looper.output_all(tie_identical_pitches=True)
-    staff = abjad.Staff(music)
+    notes = looper.output_all(tie_identical_pitches=True)
+    staff = abjad.Staff(notes)
     assert format(staff) == abjad.String.normalize(
         r"""
         \new Staff
@@ -468,13 +524,13 @@ def test_LoopByWindow_11():
 
 
 def test_LoopByWindow_12():
-    input_music = abjad.Container(r"c'4 d'4 e'4 f'4")
-    looper = auxjad.LoopByWindow(input_music,
+    container = abjad.Container(r"c'4 d'4 e'4 f'4")
+    looper = auxjad.LoopByWindow(container,
                                  window_size=(3, 4),
                                  step_size=(1, 4),
                                  )
-    music = looper.output_n(2)
-    staff = abjad.Staff(music)
+    notes = looper.output_n(2)
+    staff = abjad.Staff(notes)
     assert format(staff) == abjad.String.normalize(
         r"""
         \new Staff
@@ -491,13 +547,13 @@ def test_LoopByWindow_12():
 
 
 def test_LoopByWindow_13():
-    input_music = abjad.Container(r"c'4 d'2 e'4 f'4")
-    looper = auxjad.LoopByWindow(input_music,
+    container = abjad.Container(r"c'4 d'2 e'4 f'4")
+    looper = auxjad.LoopByWindow(container,
                                  window_size=(3, 4),
                                  step_size=(1, 4),
                                  )
-    music = looper.output_n(2, tie_identical_pitches=True)
-    staff = abjad.Staff(music)
+    notes = looper.output_n(2, tie_identical_pitches=True)
+    staff = abjad.Staff(notes)
     assert format(staff) == abjad.String.normalize(
         r"""
         \new Staff
@@ -513,8 +569,8 @@ def test_LoopByWindow_13():
 
 
 def test_LoopByWindow_14():
-    input_music = abjad.Container(r"c'4 d'4 e'4 f'4")
-    looper = auxjad.LoopByWindow(input_music,
+    container = abjad.Container(r"c'4 d'4 e'4 f'4")
+    looper = auxjad.LoopByWindow(container,
                                  window_size=(3, 4),
                                  step_size=(1, 4),
                                  )
@@ -523,14 +579,14 @@ def test_LoopByWindow_14():
 
 
 def test_LoopByWindow_15():
-    input_music = abjad.Container(r"c'4 d'4 e'4 f'4 g'4 a'4")
-    looper = auxjad.LoopByWindow(input_music,
+    container = abjad.Container(r"c'4 d'4 e'4 f'4 g'4 a'4")
+    looper = auxjad.LoopByWindow(container,
                                  window_size=(3, 4),
                                  step_size=(1, 4),
                                  head_position=(3, 4),
                                  forward_bias=0.0,
                                  )
-    notes = looper()
+    notes = looper.output_n(3)
     staff = abjad.Staff(notes)
     assert format(staff) == abjad.String.normalize(
         r"""
@@ -540,25 +596,9 @@ def test_LoopByWindow_15():
             f'4
             g'4
             a'4
-        }
-        """)
-    notes = looper()
-    staff = abjad.Staff(notes)
-    assert format(staff) == abjad.String.normalize(
-        r"""
-        \new Staff
-        {
             e'4
             f'4
             g'4
-        }
-        """)
-    notes = looper()
-    staff = abjad.Staff(notes)
-    assert format(staff) == abjad.String.normalize(
-        r"""
-        \new Staff
-        {
             d'4
             e'4
             f'4
@@ -567,8 +607,8 @@ def test_LoopByWindow_15():
 
 
 def test_LoopByWindow_16():
-    input_music = abjad.Container(r"c'4 d'4 e'4 f'4 g'4 a'4")
-    looper = auxjad.LoopByWindow(input_music,
+    container = abjad.Container(r"c'4 d'4 e'4 f'4 g'4 a'4")
+    looper = auxjad.LoopByWindow(container,
                                  window_size=(3, 4),
                                  step_size=(1, 4),
                                  head_position=(3, 4),
@@ -577,29 +617,29 @@ def test_LoopByWindow_16():
     notes = looper.output_all()
     staff = abjad.Staff(notes)
     assert format(staff) == abjad.String.normalize(
-    r"""
-    \new Staff
-    {
-        \time 3/4
-        f'4
-        g'4
-        a'4
-        e'4
-        f'4
-        g'4
-        d'4
-        e'4
-        f'4
-        c'4
-        d'4
-        e'4
-    }
-    """)
+        r"""
+        \new Staff
+        {
+            \time 3/4
+            f'4
+            g'4
+            a'4
+            e'4
+            f'4
+            g'4
+            d'4
+            e'4
+            f'4
+            c'4
+            d'4
+            e'4
+        }
+        """)
 
 
 def test_LoopByWindow_17():
-    input_music = abjad.Container(r"c'4 d'4 e'4 f'4 g'4 a'4")
-    looper = auxjad.LoopByWindow(input_music,
+    container = abjad.Container(r"c'4 d'4 e'4 f'4 g'4 a'4")
+    looper = auxjad.LoopByWindow(container,
                                  window_size=(3, 4),
                                  step_size=(1, 4),
                                  forward_bias=0.0,
@@ -607,85 +647,84 @@ def test_LoopByWindow_17():
     notes = looper.output_all()
     staff = abjad.Staff(notes)
     assert format(staff) == abjad.String.normalize(
-    r"""
-    \new Staff
-    {
-        \time 3/4
-        c'4
-        d'4
-        e'4
-    }
-    """)
+        r"""
+        \new Staff
+        {
+            \time 3/4
+            c'4
+            d'4
+            e'4
+        }
+        """)
 
 
 def test_LoopByWindow_18():
-    input_music = abjad.Container(r"c'4 d'2 e'4 f'2 ~ f'8 g'1")
-    looper = auxjad.LoopByWindow(input_music,
-                                 move_window_on_first_call=True,
+    container = abjad.Container(r"c'4 d'2 e'4 f'2 ~ f'8 g'1")
+    looper = auxjad.LoopByWindow(container,
+                                 processs_on_first_call=True,
                                  )
     notes = looper()
     staff = abjad.Staff(notes)
     assert format(staff) == abjad.String.normalize(
-    r"""
-    \new Staff
-    {
-        \time 4/4
-        c'8.
-        d'16
-        ~
-        d'4..
-        e'16
-        ~
-        e'8.
-        f'16
-    }
-    """)
+        r"""
+        \new Staff
+        {
+            \time 4/4
+            c'8.
+            d'16
+            ~
+            d'4..
+            e'16
+            ~
+            e'8.
+            f'16
+        }
+        """)
 
 
 def test_LoopByWindow_19():
-    input_music = abjad.Container(r"c'4-.\pp\< d'2--\f e'4->\ppp f'2 ~ f'8")
-    looper = auxjad.LoopByWindow(input_music)
+    container = abjad.Container(r"c'4-.\p\< d'2--\f e'4->\ppp f'2 ~ f'8")
+    looper = auxjad.LoopByWindow(container)
     staff = abjad.Staff()
-    for _ in range(2):
-        music = looper()
-        staff.append(music)
+    notes = looper.output_n(2)
+    staff = abjad.Staff(notes)
     assert format(staff) == abjad.String.normalize(
-    r"""
-    \new Staff
-    {
-        \time 4/4
-        c'4
-        \pp
-        - \staccato
-        \<
-        d'2
-        \f
-        - \tenuto
-        e'4
-        \ppp
-        - \accent
-        c'8.
-        \pp
-        - \staccato
-        \<
-        d'16
-        \f
-        - \tenuto
-        ~
-        d'4..
-        e'16
-        \ppp
-        - \accent
-        ~
-        e'8.
-        f'16
-    }
-    """)
+        r"""
+        \new Staff
+        {
+            \time 4/4
+            c'4
+            \p
+            - \staccato
+            \<
+            d'2
+            \f
+            - \tenuto
+            e'4
+            \ppp
+            - \accent
+            c'8.
+            \p
+            - \staccato
+            \<
+            d'16
+            \f
+            - \tenuto
+            ~
+            d'4..
+            e'16
+            \ppp
+            - \accent
+            ~
+            e'8.
+            f'16
+        }
+        """)
 
 
 def test_LoopByWindow_20():
-    input_music = abjad.Container(r"c'4 d'2 e'4 f'2 ~ f'8 g'1")
-    looper = auxjad.LoopByWindow(input_music)
+    container = abjad.Container(r"c'4 d'2 e'4 f'2 ~ f'8 g'1")
+    looper = auxjad.LoopByWindow(container)
     notes = looper()
     staff = abjad.Staff(notes)
     assert format(staff) == abjad.String.normalize(
@@ -704,6 +743,7 @@ def test_LoopByWindow_20():
         r"""
         \new Staff
         {
+            \time 4/4
             c'8.
             d'16
             ~
@@ -721,14 +761,16 @@ def test_LoopByWindow_20():
         r"""
         \new Staff
         {
+            \time 4/4
+            d'16
             e'16
             f'16
-            g'8
+            g'16
             ~
             g'2
             ~
-            g'8
-            a'8
+            g'8.
+            a'16
         }
         """)
     looper.head_position = 0
@@ -738,6 +780,7 @@ def test_LoopByWindow_20():
         r"""
         \new Staff
         {
+            \time 4/4
             c'16
             d'16
             e'16
@@ -748,17 +791,220 @@ def test_LoopByWindow_20():
 
 
 def test_LoopByWindow_21():
-    input_music = abjad.Container(r"c'1")
-    looper = auxjad.LoopByWindow(input_music)
+    container = abjad.Container(r"c'1")
+    looper = auxjad.LoopByWindow(container)
     assert len(looper) == 16
-    input_music = abjad.Container(r"c'1")
-    looper = auxjad.LoopByWindow(input_music,
+    container = abjad.Container(r"c'1")
+    looper = auxjad.LoopByWindow(container,
                                  step_size=(1, 4),
                                  )
     assert len(looper) == 4
-    input_music = abjad.Container(r"c'2..")
-    looper = auxjad.LoopByWindow(input_music,
+    container = abjad.Container(r"c'2..")
+    looper = auxjad.LoopByWindow(container,
                                  step_size=(1, 4),
                                  window_size=(2, 4),
                                  )
     assert len(looper) == 4
+
+
+def test_LoopByWindow_22():
+    container = abjad.Container(r"c'4 d'4 e'4 f'4")
+    looper = auxjad.LoopByWindow(container,
+                                 window_size=(3, 4),
+                                 step_size=(1, 4),
+                                 fill_with_rests=False,
+                                 )
+    notes = looper.output_n(2)
+    staff = abjad.Staff(notes)
+    assert format(staff) == abjad.String.normalize(
+        r"""
+        \new Staff
+        {
+            \time 3/4
+            c'4
+            d'4
+            e'4
+            d'4
+            e'4
+            f'4
+        }
+        """)
+
+
+def test_LoopByWindow_23():
+    random.seed(43271)
+    container = abjad.Container(r"c'4 d'4 e'4 f'4 g'4 a'4 b'4 c''4")
+    looper = auxjad.LoopByWindow(container,
+                                 window_size=(3, 4),
+                                 step_size=(1, 4),
+                                 head_position=(3, 4),
+                                 forward_bias=0.5,
+                                 )
+    notes = looper.output_n(5)
+    staff = abjad.Staff(notes)
+    assert format(staff) == abjad.String.normalize(
+        r"""
+        \new Staff
+        {
+            \time 3/4
+            f'4
+            g'4
+            a'4
+            e'4
+            f'4
+            g'4
+            d'4
+            e'4
+            f'4
+            e'4
+            f'4
+            g'4
+            d'4
+            e'4
+            f'4
+        }
+        """)
+
+
+def test_LoopByWindow_24():
+    random.seed(19814)
+    container = abjad.Container(r"c'4 d'4 e'4 f'4 g'4 a'4 b'4 c''4")
+    looper = auxjad.LoopByWindow(container,
+                                 window_size=(1, 4),
+                                 step_size=(1, 4),
+                                 max_steps=4,
+                                 )
+    notes = looper.output_n(4)
+    staff = abjad.Staff(notes)
+    assert format(staff) == abjad.String.normalize(
+        r"""
+        \new Staff
+        {
+            \time 1/4
+            c'4
+            f'4
+            b'4
+            c''4
+        }
+        """)
+
+
+def test_LoopByWindow_25():
+    container = abjad.Container(r"c'4. d'8 e'2")
+    looper = auxjad.LoopByWindow(container)
+    notes = looper()
+    staff = abjad.Staff(notes)
+    assert format(staff) == abjad.String.normalize(
+        r"""
+        \new Staff
+        {
+            \time 4/4
+            c'4.
+            d'8
+            e'2
+        }
+        """)
+    looper = auxjad.LoopByWindow(container,
+                                 boundary_depth=1,
+                                 )
+    notes = looper()
+    staff = abjad.Staff(notes)
+    assert format(staff) == abjad.String.normalize(
+        r"""
+        \new Staff
+        {
+            \time 4/4
+            c'4
+            ~
+            c'8
+            d'8
+            e'2
+        }
+        """)
+
+
+def test_LoopByWindow_26():
+    container = abjad.Container(r"c'4 d'2 e'4")
+    looper = auxjad.LoopByWindow(container,
+                                 window_size=(3, 4),
+                                 step_size=(1, 8),
+                                 )
+    staff = abjad.Staff()
+    for window in looper:
+        staff.append(window)
+    assert format(staff) == abjad.String.normalize(
+        r"""
+        \new Staff
+        {
+            \time 3/4
+            c'4
+            d'2
+            \time 3/4
+            c'8
+            d'8
+            ~
+            d'4.
+            e'8
+            \time 3/4
+            d'2
+            e'4
+            \time 3/4
+            d'4.
+            e'8
+            ~
+            e'8
+            r8
+            \time 3/4
+            d'4
+            e'4
+            r4
+            \time 3/4
+            d'8
+            e'8
+            ~
+            e'8
+            r4.
+            \time 3/4
+            e'4
+            r2
+            \time 3/4
+            e'8
+            r8
+            r2
+        }
+        """)
+    auxjad.remove_repeated_time_signatures(staff)
+    assert format(staff) == abjad.String.normalize(
+        r"""
+        \new Staff
+        {
+            \time 3/4
+            c'4
+            d'2
+            c'8
+            d'8
+            ~
+            d'4.
+            e'8
+            d'2
+            e'4
+            d'4.
+            e'8
+            ~
+            e'8
+            r8
+            d'4
+            e'4
+            r4
+            d'8
+            e'8
+            ~
+            e'8
+            r4.
+            e'4
+            r2
+            e'8
+            r8
+            r2
+        }
+        """)
