@@ -1,9 +1,11 @@
-import auxjad
-import abjad
 import random
 
+import abjad
 
-def test_complex_music_example_02():
+import auxjad
+
+
+def test_complex_music_example_01():
     random.seed(87435)
     container = abjad.Staff([
         auxjad.ArtificialHarmonic("<ds' gs'>4"),
@@ -54,18 +56,19 @@ def test_complex_music_example_02():
     # Using a looping window by elements 3 times
     looper = auxjad.LoopByNotes(container, window_size=4)
     staff = abjad.Staff()
-    for _ in range(3):
-        music = looper()
-        staff.append(music)
+    notes = looper.output_n(3)
+    staff.append(notes)
     # shuffling the last output container by the looping window 3 times
     container = abjad.Container(looper.current_window)
-    shuffler = auxjad.Shuffler(container, omit_time_signatures=True)
-    for _ in range(3):
-        music = shuffler()
-        staff.append(music)
+    shuffler = auxjad.Shuffler(container,
+                               omit_time_signatures=True,
+                               disable_rewrite_meter=True,
+                               )
+    notes = shuffler.shuffle_n(3)
+    staff.append(notes)
     # adding initial dynamics
     abjad.attach(abjad.Dynamic('ppp'), staff[0])
-    assert format(container) == abjad.String.normalize(
+    assert format(staff) == abjad.String.normalize(
         r"""
         \new Staff
         {
@@ -128,15 +131,7 @@ def test_complex_music_example_02():
                 d'
                 \tweak style #'harmonic
                 a'
-            >4.
-            ~
-            <
-                \parenthesize
-                \tweak ParenthesesItem.font-size #-4
-                d'
-                \tweak style #'harmonic
-                a'
-            >4.
+            >2.
             <c' df' g'>8
             <
                 \parenthesize
@@ -145,6 +140,22 @@ def test_complex_music_example_02():
                 \tweak style #'harmonic
                 c'
             >2.
+            <
+                \parenthesize
+                \tweak ParenthesesItem.font-size #-4
+                g
+                \tweak style #'harmonic
+                c'
+            >2.
+            r4
+            <
+                \parenthesize
+                \tweak ParenthesesItem.font-size #-4
+                d'
+                \tweak style #'harmonic
+                a'
+            >2.
+            <c' df' g'>8
             <
                 \parenthesize
                 \tweak ParenthesesItem.font-size #-4
@@ -158,49 +169,8 @@ def test_complex_music_example_02():
                 g
                 \tweak style #'harmonic
                 c'
-            >2
-            ~
-            <
-                \parenthesize
-                \tweak ParenthesesItem.font-size #-4
-                g
-                \tweak style #'harmonic
-                c'
-            >4
-            r8
-            r8
+            >2.
             <c' df' g'>8
-            <c' df' g'>8
-            <
-                \parenthesize
-                \tweak ParenthesesItem.font-size #-4
-                g
-                \tweak style #'harmonic
-                c'
-            >2
-            ~
-            <
-                \parenthesize
-                \tweak ParenthesesItem.font-size #-4
-                g
-                \tweak style #'harmonic
-                c'
-            >4
-            <
-                \parenthesize
-                \tweak ParenthesesItem.font-size #-4
-                d'
-                \tweak style #'harmonic
-                a'
-            >4.
-            ~
-            <
-                \parenthesize
-                \tweak ParenthesesItem.font-size #-4
-                d'
-                \tweak style #'harmonic
-                a'
-            >4.
             r4
         }
         """)
@@ -259,22 +229,19 @@ def test_complex_music_example_02():
     # Using a looping window 3 times with the container created above as input
     looper = auxjad.LoopByWindow(container)
     staff = abjad.Staff()
-    for _ in range(3):
-        music = looper()
-        staff.append(music)
+    notes = looper.output_n(3)
+    staff.append(notes)
     # shuffling the last output container by the looping window 3 times
     container = abjad.Container(looper.current_window)
     shuffler = auxjad.Shuffler(container, omit_time_signatures=True)
-    for _ in range(3):
-        music = shuffler()
-        staff.append(music)
+    notes = shuffler.shuffle_n(3)
+    staff.append(notes)
     # continuing with the looping process 3 more times using the last shuffled
     # container
     container = abjad.Container(shuffler.current_window)
     looper = auxjad.LoopByWindow(container, window_size=(3, 4))
-    for _ in range(3):
-        music = looper()
-        staff.append(music)
+    notes = looper.output_n(3)
+    staff.append(notes)
     # removing repeated dynamics
     auxjad.remove_repeated_dynamics(staff)
     assert format(staff) == abjad.String.normalize(
@@ -313,6 +280,13 @@ def test_complex_music_example_02():
             ~
             c'4.
             af'4.
+            bf'8
+            \mf
+            - \tenuto
+            af'4.
+            \mp
+            c'2
+            - \tenuto
             c'2
             - \tenuto
             bf'8
@@ -320,38 +294,29 @@ def test_complex_music_example_02():
             - \tenuto
             af'4.
             \mp
-            bf'8
-            \mf
-            - \tenuto
-            c'8
-            \mp
-            - \tenuto
-            ~
-            c'4.
-            af'4.
             \time 3/4
+            c'2
+            - \tenuto
             bf'8
             \mf
             - \tenuto
-            c'8
-            \mp
-            - \tenuto
-            ~
-            c'4.
             af'8
+            \mp
+            c'4..
+            - \tenuto
             bf'16
             \mf
             - \tenuto
-            c'8.
-            \mp
-            - \tenuto
             ~
-            c'4
-            ~
-            c'16
+            bf'16
             af'8.
-            c'2
+            \mp
+            c'4.
+            - \tenuto
+            bf'8
+            \mf
             - \tenuto
             af'4
+            \mp
         }
         """)
