@@ -1,5 +1,6 @@
 import abjad
 import pytest
+
 import auxjad
 
 
@@ -37,6 +38,24 @@ def test_repeat_container_01():
             e'4
         }
         """)
+    assert format(staff) == abjad.String.normalize(
+        r"""
+        \new Staff
+        {
+            {
+                \time 3/4
+                c'4
+                d'4
+                e'4
+                c'4
+                d'4
+                e'4
+                c'4
+                d'4
+                e'4
+            }
+        }
+        """)
 
 
 def test_repeat_container_02():
@@ -90,7 +109,7 @@ def test_repeat_container_04():
     container = abjad.Container(r"c'4 d'4 e'4")
     output_container = auxjad.repeat_container(container,
                                                3,
-                                               omit_all_time_signatures=True,
+                                               omit_time_signatures=True,
                                                )
     assert format(output_container) == abjad.String.normalize(
         r"""
@@ -159,3 +178,25 @@ def test_repeat_container_07():
     container = abjad.Container(r"\time 5/4 g''1 \time 4/4 f'1")
     with pytest.raises(ValueError):
         assert auxjad.repeat_container(container, 4)
+
+
+def test_repeat_container_08():
+    container = abjad.Staff(r"\clef bass c4 d4 e4")
+    output_staff = auxjad.repeat_container(container, 3)
+    assert format(output_staff) == abjad.String.normalize(
+        r"""
+        \new Staff
+        {
+            \time 3/4
+            \clef "bass"
+            c4
+            d4
+            e4
+            c4
+            d4
+            e4
+            c4
+            d4
+            e4
+        }
+        """)
